@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Exports an error box that can be used to pass the errors we need. 
 
@@ -14,8 +13,9 @@ MitoError box to avoid creating too many new classes!
 See more about why we use errors here: 
 https://stackoverflow.com/questions/16138232/is-it-a-good-practice-to-use-try-except-else-in-python
 """
+import re
 import traceback
-from typing import Any, Collection, Set, List
+from typing import Any, Collection, Optional, Set, List
 
 from mitosheet.types import ColumnHeader
 
@@ -132,7 +132,7 @@ def make_invalid_formula_error(formula: str, to_fix: str=None, error_modal: bool
     )
 
 
-def make_cast_value_to_type_error(value: str, target_type: str, error_modal: bool=True) -> MitoError:
+def make_cast_value_to_type_error(value: str, column_dtype: str, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a cast_value_to_type_error.
 
@@ -142,8 +142,8 @@ def make_cast_value_to_type_error(value: str, target_type: str, error_modal: boo
     """
     return MitoError(
         'cast_value_to_type_error',
-        'Invalid Value for ' + target_type + 'Column',
-        'The value ' + value + ' could not be cast to the type ' + target_type + '. Please enter a different value.' , 
+        'Invalid Value for ' + column_dtype + 'Series',
+        'The value ' + value + ' could not be cast to the type ' + column_dtype + '. Please enter a different value.' , 
         error_modal=error_modal
     )
 
@@ -161,20 +161,6 @@ def make_circular_reference_error(error_modal: bool=True) -> MitoError:
         error_modal=error_modal
     )
 
-def make_wrong_column_metatype_error(column_header: ColumnHeader, error_modal: bool=True) -> MitoError:
-    """
-    Helper function for creating a wrong_column_metatype_error.
-
-    Occurs when:
-    -  a user edits a column to a formula when it is not a formula type column.
-    """
-    return MitoError(
-        'wrong_column_metatype_error',
-        'Wrong Column Type',
-        f'Sorry, the column {column_header} is a data column. We don\'t currently support changing it to a formula.',
-        error_modal=error_modal
-    )
-
 def make_invalid_column_headers_error(column_headers: List[ColumnHeader]) -> MitoError:
     """
     Helper function for creating a invalid_column_headers_error.
@@ -255,18 +241,27 @@ def make_unsupported_function_error(functions: Set[str], error_modal: bool=True)
         error_modal=error_modal
     )
 
-def make_invalid_column_delete_error(column_headers: Collection[ColumnHeader], dependents: Collection[ColumnHeader]) -> MitoError:
+
+def make_invalid_column_delete_error(column_headers: Collection[ColumnHeader], dependents: Optional[Collection[ColumnHeader]]=None) -> MitoError:
     """
     Helper function for creating a invalid_column_delete_error.
 
     Occurs when:
-    -  the user deletes a column that is referenced by other columns
+    - the user deletes a column that is referenced by other columns
+    - the user deletes a column that does not exist
     """
+    if dependents is not None:
+        header = 'Column Has Dependents'
+        to_fix = f'{(", ").join(map(str, column_headers))} cannot be deleted, as {"they are" if len(column_headers) > 1 else "it is"} referenced in {(", ".join(map(str, dependents)))}. Please remove these references before deleting.'
+    else:
+        header = 'Column Does not exist'
+        to_fix = f'{(", ").join(map(str, column_headers))} cannot be deleted, as not all of these columns exist.'
+   
 
     return MitoError(
         'invalid_column_delete_error',
-        'Column Has Dependents',
-        f'{(", ").join(map(str, column_headers))} cannot be deleted, as {"they are" if len(column_headers) > 1 else "it is"} referenced in {(", ".join(map(str, dependents)))}. Please remove these references before deleting.'
+        header,
+        to_fix
     )
 
 def make_invalid_arguments_error(function: str) -> MitoError:
@@ -392,6 +387,25 @@ def make_is_directory_error(file_name: str) -> MitoError:
     )
 
 
+def make_no_analysis_error(analysis_id: str, error_modal: bool=True) -> MitoError:
+    """
+    Helper function for creating a no_analysis_error.
+
+    Occurs when a user tries to replay an analysis that they don't have access to in 
+    their .mito folder
+    """
+    to_fix = f'When you call mitosheet.sheet() and there is a code cell below that contains an analysis ID, \
+    Mito tries to replay that analysis. However, you do not have access to the analysis {analysis_id} so Mito is unable to replay it. \
+    Add a new code cell below the mitosheet.sheet() call to start a new analysis.' 
+    
+    return MitoError(
+        'no_analysis_error', 
+        "You don't have access to the analysis",
+        to_fix,
+        error_modal=error_modal
+    )
+
+
 ARG_FULL_NAME = {
     'int': 'number',
     'float': 'number',
@@ -427,7 +441,13 @@ def make_operator_type_error(operator: str, arg_one_type: str, arg_two_type: str
     )
 
 def get_recent_traceback() -> str:
-    return traceback.format_exc()
+    """
+    Helper function that returns the most recent traceback, with the file paths
+    stripped to remove all but the mitosheet file names for ease in debugging.
+    
+    Inspired by https://stackoverflow.com/questions/25272368/hide-file-from-traceback
+    """
+    return re.sub(r'File ".*[\\/]([^\\/]+.py)"', r'File "\1"', traceback.format_exc())
 
 def get_recent_traceback_as_list() -> List[str]:
     """
@@ -440,4 +460,4 @@ def get_recent_traceback_as_list() -> List[str]:
     and thus we avoid things getting chopped this way.
     """
     # NOTE: We ignore empty lines, as they add no information
-    return [line for line in traceback.format_exc().split('\n') if line != '']
+    return [line for line in get_recent_traceback().split('\n') if line != '']
