@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 For going to a boolean series.
 """
@@ -12,11 +11,10 @@ from typing import Any
 
 import numpy as np
 import pandas as pd
-from mitosheet.sheet_functions.types.utils import (BOOLEAN_SERIES,
-                                                   DATETIME_SERIES,
-                                                   NUMBER_SERIES,
-                                                   STRING_SERIES,
-                                                   get_mito_type)
+from mitosheet.sheet_functions.types.utils import (is_bool_dtype,
+                                                   is_datetime_dtype,
+                                                   is_number_dtype,
+                                                   is_string_dtype)
 
 
 def to_boolean_series(
@@ -27,21 +25,20 @@ def to_boolean_series(
     Converts the given object to a boolean series. Note that on_uncastable_arg_element
     is irrelevant here, as anything can be turned into a boolean. 
     """
-    from_type = get_mito_type(unknown_object)
 
     # If it is not a series, we put it in a series, and get the type again
-    if not from_type.endswith('series'):
+    if not isinstance(unknown_object, pd.Series):
         unknown_object = pd.Series([unknown_object])
-        from_type = get_mito_type(unknown_object)
 
-    if from_type == BOOLEAN_SERIES:
+    column_dtype = str(unknown_object.dtype)
+    if is_bool_dtype(column_dtype):
         return unknown_object
-    elif from_type == DATETIME_SERIES:
+    elif is_datetime_dtype(column_dtype):
         # For now, we treat all dates as true, and NaN values as False
         return ~unknown_object.isna()
-    elif from_type == NUMBER_SERIES:
+    elif is_number_dtype(column_dtype):
         return unknown_object.fillna(False).astype('bool')
-    elif from_type == STRING_SERIES:
+    elif is_string_dtype(column_dtype):
         string_to_bool_conversion_dict = {
             '1': True,
             '1.0': True,
@@ -54,6 +51,8 @@ def to_boolean_series(
             't': True,
             'Y': True,
             'y': True,
+            'Yes': True,
+            'yes': True,
             #########################
             '0': False,
             '0.0': False,
@@ -65,7 +64,9 @@ def to_boolean_series(
             'F': False,
             'f': False,
             'N': False,
-            'n': False
+            'n': False,
+            'No': False,
+            'no': False
         }
         # Convert any NaN values to False
         return unknown_object.map(string_to_bool_conversion_dict).fillna(False)
