@@ -10,6 +10,7 @@ This file contains helpful functions and classes for testing operations.
 import json
 from functools import wraps
 from typing import Any, Dict, List, Optional, Tuple, Union
+from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
 from numpy import number
 
@@ -126,6 +127,12 @@ class MitoWidgetTestWrapper:
         # NOTE: we don't add comments to this testing functionality, so that 
         # we don't have to change tests if we update comments
         return transpile(self.mito_widget.steps_manager, add_comments=False)
+    
+    @property
+    def optimized_code_chunks(self):
+        # NOTE: we don't add comments to this testing functionality, so that 
+        # we don't have to change tests if we update comments
+        return get_code_chunks(self.mito_widget.steps_manager.steps, optimize=True)
 
     @property
     def curr_step_idx(self):
@@ -416,7 +423,8 @@ class MitoWidgetTestWrapper:
             self, 
             sheet_index: int, 
             column_header: ColumnHeader,
-            sort_direction: str
+            sort_direction: str,
+            step_id: str=None
         ) -> bool:
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
@@ -430,7 +438,7 @@ class MitoWidgetTestWrapper:
                 'event': 'edit_event',
                 'id': get_new_id(),
                 'type': 'sort_edit',
-                'step_id': get_new_id(),
+                'step_id': get_new_id() if step_id is None else step_id,
                 'params': {
                     'sheet_index': sheet_index,
                     'column_id': column_id,
