@@ -1,17 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
-from copy import copy
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 from typing import List
 
+from mitosheet.types import StepsManagerType
 
 REDO_EVENT = 'redo'
 REDO_PARAMS: List[str] = []
 
-def execute_redo_update(steps_manager):
+def execute_redo_update(steps_manager: StepsManagerType) -> None:
     steps_manager.execute_redo()
 
 REDO_UPDATE = {
